==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/es.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "El almacenamiento no esta disponible temporalmente",
    "Storage invalid" : "Almacenamiento inválido",
    "Unknown error" : "Error desconocido",
    "Files" : "Archivos",
    "All files" : "Todos los archivos",
    "Recent" : "Reciente",
    "File could not be found" : "El archivo no se ha encontrado",
    "Home" : "Particular",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "No se pudo crear la carpeta \"{dir}\"",
    "Upload cancelled." : "Subida cancelada.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta de destino \"{dir}\" ya no existe",
    "Not enough free space" : "No hay espacio libre suficiente",
    "Uploading..." : "Subiendo...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Renombrar",
    "Move" : "Mover",
    "Target folder" : "Directorio destino",
    "Delete" : "Eliminar",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Unshare" : "Dejar de compartir",
    "Could not load info for file \"{file}\"" : "No se pudo cargar información para el archivo \"{file}\"",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "No se ha podido determinar la fecha",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contáctese con el administrador",
    "Could not move \"{file}\", target exists" : "No se pudo mover \"{file}\", destino ya existe",
    "Could not move \"{file}\"" : "No se pudo mover \"{file}\"",
    "{newName} already exists" : "{newName} ya existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "No se pudo renombrar \"{fileName}\", ya no existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya se utiliza en la carpeta \"{dir}\". Por favor elija un nombre diferente.",
    "Could not rename \"{fileName}\"" : "No se pudo renombrar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No se pudo crear archivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No se pudo crear archivo \"{file}\" porque ya existe",
    "Could not create folder \"{dir}\" because it already exists" : "No se pudo crear la carpeta \"{dir}\" porque ya existe",
    "Error deleting file \"{fileName}\"." : "Error al borrar el archivo \"{fileName}\".",
    "No search results in other folders for '{tag}{filter}{endtag}'" : "No hay resultados de búsqueda en otras carpetas para '{tag}{filter}{endtag}'",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos"],
    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí.",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "El almacén de {owner} está repleto, ¡los archivos no se actualizarán ni sincronizarán más!",
    "Your storage is full, files can not be updated or synced anymore!" : "Su almacenamiento está lleno, ¡los archivos no se actualizarán ni sincronizarán más!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "El almacén de {owner} está casi lleno en un ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su almacenamiento está casi lleno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidencias '{filter}'","coincidencia '{filter}'"],
    "View in folder" : "Ver en carpeta",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Agregado a Favoritos",
    "Favorite" : "Favorito",
    "Copy local link" : "Copiar enlace local",
    "Folder" : "Carpeta",
    "New folder" : "Nueva carpeta",
    "Upload" : "Subir",
    "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
    "Added to favorites" : "Agregado a favoritos",
    "Removed from favorites" : "Borrado de favoritos",
    "You added {file} to your favorites" : "Agregado {file} a tus favoritos",
    "You removed {file} from your favorites" : "Borrado {file} de tus favoritos",
    "File changes" : "Cambios del archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Cambiado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "You created {file}" : "Ha creado {file}",
    "{user} created {file}" : "{user} ha creado {file}",
    "{file} was created in a public folder" : "{file} se ha creado en una carpeta pública",
    "You changed {file}" : "Usted ha cambiado {file}",
    "{user} changed {file}" : "{user} ha cambiado {file}",
    "You deleted {file}" : "Usted ha borrado {file}",
    "{user} deleted {file}" : "{user} eliminó {file}",
    "You restored {file}" : "Usted restauró {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} to {newfile}" : "Ha renombrado {oldfile} como {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha renombrado {oldfile } como {newfile}",
    "You moved {oldfile} to {newfile}" : "Ha movido {oldfile } a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo fue agregado o borrado de tus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong> o <strong>renombrado</strong>.",
    "A new file or folder has been <strong>created</strong>" : "Se ha <strong>creado</strong> un nuevo archivo o carpeta",
    "A new file or folder has been <strong>deleted</strong>" : "Un nuevo archivo o carpeta ha sido <strong>eliminado</strong>.",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notificaiones acerca de la creación y cambios de sus <strong>archivos favoritos</strong><em>(Stream only)</em>",
    "A new file or folder has been <strong>restored</strong>" : "Un nuevo archivo o carpeta ha sido <strong>restaurado</strong>.",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "File handling" : "Administración de archivos",
    "Maximum upload size" : "Tamaño máximo de subida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podría tardar 5 minutos para que se realicen los cambios.",
    "Missing permissions to edit from here." : "Faltan permisos para poder editar desde aquí.",
    "Settings" : "Ajustes",
    "Show hidden files" : "Mostrar archivos ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Introduce esta dirección <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\"> en el cliente de ownCloud para acceder a tus archivos a través de él</a>",
    "No files in here" : "Aquí no hay archivos",
    "Upload some content or sync with your devices!" : "Suba contenidos o sincronice sus dispositivos.",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "No favorites" : "No hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que usted marque como favoritos",
    "Shared with you" : "Compartido con usted",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por enlace",
    "Tags" : "Etiquetas",
    "Deleted files" : "Archivos eliminados",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo archivo de texto.txt",
    "Storage not available" : "Almacenamiento no disponible",
    "Unable to set upload directory." : "Incapaz de crear directorio de subida.",
    "Invalid Token" : "Token Inválido",
    "No file was uploaded. Unknown error" : "No se subió ningún archivo. Error desconocido",
    "There is no error, the file uploaded with success" : "No hubo ningún problema, el archivo se subió con éxito",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "El archivo subido sobrepasa la directiva 'upload_max_filesize' en php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo subido sobrepasa la directiva 'MAX_FILE_SIZE' especificada en el formulario HTML",
    "The uploaded file was only partially uploaded" : "El archivo cargado sólo se ha subido parcialmente",
    "No file was uploaded" : "No se subió ningún archivo",
    "Missing a temporary folder" : "Falta la carpeta temporal",
    "Failed to write to disk" : "Falló al escribir al disco",
    "Not enough storage available" : "No hay suficiente espacio disponible",
    "The target folder has been moved or deleted." : "La carpeta de destino fue movida o eliminada.",
    "Upload failed. Could not find uploaded file" : "Actualización fallida. No se pudo encontrar el archivo subido",
    "Upload failed. Could not get file info." : "Actualización fallida. No se pudo obtener información del archivo.",
    "Invalid directory." : "Directorio inválido.",
    "Total file size {size1} exceeds upload limit {size2}" : "El tamaño total del archivo {size1} excede el límite {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Error subiendo el archivo \"{fileName}\": {message}",
    "Could not get result from server." : "No se pudo obtener respuesta del servidor.",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} hora{plural_s} pendiente",
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minuto{plural_s} pendiente",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "{seconds} second{plural_s} left" : "{seconds} segundo{plural_s} pendiente",
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "En cualquier momento...",
    "Soon..." : "Dentro de poco...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La subida del archivo está en proceso. Si sale de la página ahora, la subida será cancelada.",
    "No entries in this folder match '{filter}'" : "No hay resultados que coincidan con '{filter}'",
    "Local link" : "Enlace local",
    "{newname} already exists" : "{newname} ya existe",
    "A file or folder has been <strong>changed</strong>" : "Se ha <strong>modificado</strong> un archivo o carpeta",
    "A file or folder has been <strong>deleted</strong>" : "Se ha <strong>eliminado</strong> un archivo o carpeta",
    "A file or folder has been <strong>restored</strong>" : "Se ha <strong>restaurado</strong> un archivo o carpeta",
    "You created %1$s" : "Ha creado %1$s",
    "%2$s created %1$s" : "%2$s ha creado %1$s",
    "%1$s was created in a public folder" : "%1$s ha sido creado en una carpeta pública",
    "You changed %1$s" : "Ha modificado %1$s",
    "%2$s changed %1$s" : "%2$s ha modificado %1$s",
    "You deleted %1$s" : "Ha eliminado %1$s",
    "%2$s deleted %1$s" : "%2$s ha eliminado %1$s",
    "You restored %1$s" : "Usted restauró %1$s",
    "%2$s restored %1$s" : "%2$s recuperó %1$s",
    "Changed by %2$s" : "Cambiado por %2$s",
    "Deleted by %2$s" : "Eliminado por %2$s",
    "Restored by %2$s" : "Restaurado por %2$s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/es.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "El almacenamiento no esta disponible temporalmente",
    "Storage invalid" : "Almacenamiento inválido",
    "Unknown error" : "Error desconocido",
    "All files" : "Todos los archivos",
    "Recent" : "Reciente",
    "File could not be found" : "El archivo no se ha encontrado",
    "Home" : "Particular",
    "Close" : "Cerrar",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "No se pudo crear la carpeta \"{dir}\"",
    "Upload cancelled." : "Subida cancelada.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No ha sido posible subir {filename} porque es un directorio o tiene 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hay suficiente espacio libre. Quiere subir {size1} pero solo quedan {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La carpeta de destino \"{dir}\" ya no existe",
    "Not enough free space" : "No hay espacio libre suficiente",
    "Uploading..." : "Subiendo...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Actions" : "Acciones",
    "Download" : "Descargar",
    "Rename" : "Renombrar",
    "Move" : "Mover",
    "Target folder" : "Directorio destino",
    "Delete" : "Eliminar",
    "Disconnect storage" : "Desconectar almacenamiento",
    "Unshare" : "Dejar de compartir",
    "Could not load info for file \"{file}\"" : "No se pudo cargar información para el archivo \"{file}\"",
    "Files" : "Archivos",
    "Details" : "Detalles",
    "Select" : "Seleccionar",
    "Pending" : "Pendiente",
    "Unable to determine date" : "No se ha podido determinar la fecha",
    "This operation is forbidden" : "Esta operación está prohibida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verifique los registros o contáctese con el administrador",
    "Could not move \"{file}\", target exists" : "No se pudo mover \"{file}\", destino ya existe",
    "Could not move \"{file}\"" : "No se pudo mover \"{file}\"",
    "{newName} already exists" : "{newName} ya existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "No se pudo renombrar \"{fileName}\", ya no existe",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{targetName}\" ya se utiliza en la carpeta \"{dir}\". Por favor elija un nombre diferente.",
    "Could not rename \"{fileName}\"" : "No se pudo renombrar \"{fileName}\"",
    "Could not create file \"{file}\"" : "No se pudo crear archivo \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No se pudo crear archivo \"{file}\" porque ya existe",
    "Could not create folder \"{dir}\" because it already exists" : "No se pudo crear la carpeta \"{dir}\" porque ya existe",
    "Error deleting file \"{fileName}\"." : "Error al borrar el archivo \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No hay resultados de búsqueda en otras carpetas para  {tag}{filter}{endtag}",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas"],
    "_%n file_::_%n files_" : ["%n archivo","%n archivos"],
    "{dirs} and {files}" : "{dirs} y {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos"],
    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos"],
    "New" : "Nuevo",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es un tipo de archivo permitido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "El almacén de {owner} está repleto, ¡los archivos no se actualizarán ni sincronizarán más!",
    "Your storage is full, files can not be updated or synced anymore!" : "Su almacenamiento está lleno, ¡los archivos no se actualizarán ni sincronizarán más!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "El almacén de {owner} está casi lleno en un ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Su almacenamiento está casi lleno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidencias '{filter}'","coincidencia '{filter}'"],
    "View in folder" : "Ver en carpeta",
    "Copied!" : "¡Copiado!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiae enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
    "Path" : "Ruta",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Agregado a favoritos",
    "Favorite" : "Favorito",
    "New folder" : "Nueva carpeta",
    "Upload file" : "Subir archivo",
    "An error occurred while trying to update the tags" : "Se produjo un error al tratar de actualizar las etiquetas",
    "Added to favorites" : "Agregado a favoritos",
    "Removed from favorites" : "Borrado de favoritos",
    "You added {file} to your favorites" : "Agregado {file} a tus favoritos",
    "You removed {file} from your favorites" : "Borrado {file} de tus favoritos",
    "File changes" : "Cambios del archivo",
    "Created by {user}" : "Creado por {user}",
    "Changed by {user}" : "Cambiado por {user}",
    "Deleted by {user}" : "Borrado por {user}",
    "Restored by {user}" : "Restaurado por {user}",
    "Renamed by {user}" : "Renombrado por {user}",
    "Moved by {user}" : "Movido por {user}",
    "\"remote user\"" : "\"usuario remoto\"",
    "You created {file}" : "Ha creado {file}",
    "{user} created {file}" : "{user} ha creado {file}",
    "{file} was created in a public folder" : "{file} se ha creado en una carpeta pública",
    "You changed {file}" : "Usted ha cambiado {file}",
    "{user} changed {file}" : "{user} ha cambiado {file}",
    "You deleted {file}" : "Usted ha borrado {file}",
    "{user} deleted {file}" : "{user} eliminó {file}",
    "You restored {file}" : "Usted restauró {file}",
    "{user} restored {file}" : "{user} restauró {file}",
    "You renamed {oldfile} to {newfile}" : "Ha renombrado {oldfile} como {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha renombrado {oldfile } como {newfile}",
    "You moved {oldfile} to {newfile}" : "Ha movido {oldfile } a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo fue agregado o borrado de tus <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un archivo o carpeta ha sido <strong>cambiado</strong> o <strong>renombrado</strong>",
    "A new file or folder has been <strong>created</strong>" : "Se ha <strong>creado</strong> un nuevo archivo o carpeta",
    "A file or folder has been <strong>deleted</strong>" : "Un archivo o carpeta ha sido <strong>eliminado</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar las notificaciones acerca de la creación y cambios de sus <strong>archivos favoritos</strong> <em>(solo flujos)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un archivo o carpeta ha sido <strong>restaurado</strong>",
    "Unlimited" : "Ilimitado",
    "Upload (max. %s)" : "Subida (máx. %s)",
    "File handling" : "Administración de archivos",
    "Maximum upload size" : "Tamaño máximo de subida",
    "max. possible: " : "máx. posible:",
    "Save" : "Guardar",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM podría tardar 5 minutos para que se realicen los cambios.",
    "Missing permissions to edit from here." : "Faltan permisos para poder editar desde aquí.",
    "%s of %s used" : "%s de %s usado",
    "%s used" : "usado %s",
    "Settings" : "Ajustes",
    "Show hidden files" : "Mostrar archivos ocultos",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Usa esta dirección para <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">acceder tus archivos mediante WebDAV</a>",
    "No files in here" : "Aquí no hay archivos",
    "Upload some content or sync with your devices!" : "¡Suba contenidos o sincronice sus dispositivos!",
    "No entries found in this folder" : "No hay entradas en esta carpeta",
    "Select all" : "Seleccionar todo",
    "Upload too large" : "Subida demasido grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
    "No favorites yet" : "Aún no hay favoritos",
    "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que usted marque como favoritos",
    "Shared with you" : "Compartido con usted",
    "Shared with others" : "Compartido con otros",
    "Shared by link" : "Compartido por enlace",
    "Tags" : "Etiquetas",
    "Deleted files" : "Archivos eliminados",
    "Text file" : "Archivo de texto",
    "New text file.txt" : "Nuevo archivo de texto.txt",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} hora restante","{hours}:{minutes}:{seconds} horas restantes"],
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} minuto restante","{minutes}:{seconds} minutos restantes"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} segundo restante","{seconds} segundos restantes"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "En cualquier momento...",
    "Soon..." : "Dentro de poco...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "La subida del archivo está en proceso. Si sale de la página ahora, la subida será cancelada.",
    "Copy local link" : "Copiar enlace local",
    "Folder" : "Carpeta",
    "Upload" : "Subir",
    "A new file or folder has been <strong>deleted</strong>" : "Un nuevo archivo o carpeta ha sido <strong>eliminado</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Un nuevo archivo o carpeta ha sido <strong>restaurado</strong>",
    "No favorites" : "No hay favoritos"
},
"nplurals=2; plural=(n != 1);");
